# -*- coding: utf-8 -*-
# Generated by Django 1.11.8 on 2018-01-13 01:22
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oauth_provider', '0001_initial'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='consumer',
            name='id',
        ),
        migrations.RemoveField(
            model_name='nonce',
            name='id',
        ),
        migrations.RemoveField(
            model_name='scope',
            name='id',
        ),
        migrations.RemoveField(
            model_name='token',
            name='id',
        ),
        migrations.AlterField(
            model_name='consumer',
            name='key',
            field=models.CharField(max_length=1024, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='consumer',
            name='secret',
            field=models.CharField(blank=True, max_length=1024),
        ),
        migrations.AlterField(
            model_name='nonce',
            name='consumer_key',
            field=models.CharField(max_length=1024),
        ),
        migrations.AlterField(
            model_name='nonce',
            name='key',
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='scope',
            name='name',
            field=models.CharField(max_length=255, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='token',
            name='key',
            field=models.CharField(default='', max_length=32, primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='token',
            name='secret',
            field=models.CharField(blank=True, max_length=1024, null=True),
        ),
    ]
